<!-- 设备监测报表 -->
<template>
    <page-container>
        <FullPage>
            <div class="monitor-report">
                <div class="tree-nav">
                    <j-tree v-model:expandedKeys="expandedKeys" v-model:selectedKeys="selectedKeys"
                        v-model:checkedKeys="checkedKeys" checkable :tree-data="treeData">
                        <template #title="{ title, key }">
                            <span v-if="key === '0-0-1-0'" style="color: #1890ff">{{ title }}
                            </span>
                            <template v-else>{{ title }}</template>
                        </template>
                    </j-tree>
                </div>
                <div class="content">
                    <j-search :columns="searchs" @search="handleSearch" :type="value" />

                    <JProTable ref="tableRef" :columns="table.columns" :request="queryMJG" model="TABLE"
                        v-model:expandedRowKeys="expandedRowKeys" :scroll="{ y: 550 }" :defaultParams="{
                            paging: false,
                            sorts: [
                                { name: 'sortIndex', order: 'asc' },
                                {
                                    name: 'createTime',
                                    order: 'desc',
                                },
                            ],
                        }" :params="params" :loading="tableLoading">
                        <template #headerTitle>
                            <!-- <j-space>
                  <PermissionButton type="primary" @click="add" hasPermission="device/Category:add">
                    <template #icon>
                      <AIcon type="PlusOutlined" />
                    </template>
                    新增密集柜
                  </PermissionButton>
                </j-space> -->
                            <span class="table-title">空气净化器设备2022-03-10报表</span>
                        </template>
                        <template #action="slotProps">
                            <j-space>
                                <template v-for="(i, index) in getActions(
                                    slotProps,
                                    'table',
                                )" :key="i.key">
                                    <PermissionButton :disabled="i.disabled" :popConfirm="i.popConfirm" :hasPermission="'device/Category:' + i.key
                                        " :tooltip="{
        ...i.tooltip,
    }" @click="i.onClick" type="link" style="padding: 0px"
                                        :danger="i.key === 'delete'">
                                        <template #icon>
                                            <AIcon :type="i.icon" />
                                        </template>
                                    </PermissionButton>
                                    <!-- <j-divider v-if="actionLength - 1 != index" type="vertical" /> -->
                                </template>
                            </j-space>
                        </template>
                    </JProTable>
                </div>
            </div>
        </FullPage>
    </page-container>
</template>
<script lang="ts" name="DeviceMonitor" setup>
import type { TreeProps } from 'ant-design-vue';
import { queryMJG, deleteMJG } from '@/api/device-manager/mjg';
import type { ActionsType } from '@/components/Table/index';
import { message } from 'jetlinks-ui-components';
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';
import { ref } from 'vue';

const tableRef = ref<Record<string, any>>({});
const modifyRef = ref();
let actionLength = ref<number>(0);
const isChild = ref(0);
const currentForm = ref({});
const title = ref('');
const isAdd = ref(0);
let params = ref();
const tableLoading = ref(false);
const expandedRowKeys = ref<any>([]);
const value = ref('object');
const treeData: TreeProps['treeData'] = [
    {
        title: '全部',
        key: '0-0',
        children: [
            {
                title: '环境监测',
                key: '0-0-0',
                disabled: true,
                children: [
                    {
                        title: '二级类目',
                        key: '0-0-0-0',
                        disableCheckbox: true,
                    },
                    { title: '二级类目', key: '0-0-0-1' },
                ],
            },
            {
                title: '库房监测',
                key: '0-0-1',
                children: [{ key: '0-0-1-0', title: '二级类目' }],
            },
        ],
    },
];
const expandedKeys = ref<string[]>(['0-0-0', '0-0-1']);
const selectedKeys = ref<string[]>(['0-0-0', '0-0-1']);
const checkedKeys = ref<string[]>(['0-0-0', '0-0-1']);

const searchs = ref<any>([
    {
        title: '采集刻度',
        dataIndex: 'type',
        search: {
            type: 'select',
            options: [
                { label: '分钟', value: 1 },
                { label: '小时', value: 2 },
                { label: '天', value: 3 },
                { label: '月', value: 4 },
            ],
            componentProps: {
                placeholder: '请选择类型',
            },
        },
    },
    {
        title: '开始时间',
        dataIndex: 'time',
        search: {
            type: 'date',
            componentProps: {
                placeholder: '请选择开始时间',
            },
        },
    },
    {
        title: '结束时间',
        dataIndex: 'time',
        search: {
            type: 'date',
            componentProps: {
                placeholder: '请选择结束时间',
            },
        },
    },
]);

/**
 * 搜索
 */
const handleSearch = (e: any) => {
    let arr = [];
    for (let key in e) {
        arr.push(key + '=' + e[key]);
    }

    params.value = { where: arr.join(' and ') };
    expandedRowKeys.value = [];
};
// onMounted(() => {});

/**
 * 操作栏按钮
 */
const getActions = (
    data: Partial<Record<string, any>>,
    type: 'table',
): ActionsType[] => {
    if (!data) return [];
    const actions = [
        // {
        //     key: 'view',
        //     text: '详情',
        //     tooltip: {
        //         title: '详情',
        //     },
        //     icon: 'UnorderedListOutlined',
        //     onClick: async () => {
        //         title.value = '密集柜详情';
        //         isAdd.value = 2;
        //         currentForm.value = data;
        //         nextTick(() => {
        //             // modifyRef.value.show(data);
        //         });
        //     },
        // },
        {
            key: 'update',
            text: '编辑',
            tooltip: {
                title: '编辑',
            },
            icon: 'EditOutlined',
            onClick: async () => {
                title.value = '编辑单位信息';
                isAdd.value = 2;
                currentForm.value = data;
                nextTick(() => {
                    modifyRef.value.show(data);
                });
            },
        },
        {
            key: 'delete',
            text: '删除',
            tooltip: {
                title: '删除',
            },
            icon: 'DeleteOutlined',
            popConfirm: {
                title: '确认删除?',
                okText: ' 确定',
                cancelText: '取消',
                onConfirm: async () => {
                    const resp = await deleteMJG(data.id);
                    if (resp.status === 200) {
                        message.success('操作成功！');
                        tableRef.value.reload();
                    } else {
                        message.error('操作失败！');
                    }
                },
            },
        },
    ];
    actionLength.value = actions.length;

    return actions;
};
const table = reactive({
    columns: [
        {
            title: '日期',
            dataIndex: 'code',
            key: 'code',
        },
        {
            title: '温度',
            dataIndex: 'name',
            key: 'name',
        },
        {
            title: '湿度',
            dataIndex: 'warehouseId',
            key: 'warehouseId',
        },
        {
            title: 'PM2.5',
            dataIndex: 'storageType',
            key: 'storageType',
        },
        {
            title: 'TVOC级',
            dataIndex: 'linkAddress',
            key: 'linkAddress',
        },
        {
            title: '风速值',
            dataIndex: 'cols',
            key: 'cols',
        },
        {
            title: '报警状态',
            dataIndex: 'groups',
            key: 'groups',
        },
        {
            title: '开关状态',
            dataIndex: 'layers',
            key: 'layers',
        },
        {
            title: '备注',
            dataIndex: 'memo',
            key: 'memo',
        },
        //   {
        //     title: '操作',
        //     key: 'action',
        //     fixed: 'right',
        //     ellipsis: true,
        //     scopedSlots: true,
        //     // width: 125,
        //   },
    ],
    /**
     * 添加产品分类
     */
    add: async () => {
        title.value = '新增密集柜';
        isAdd.value = 0;
        isChild.value = 3;
        nextTick(() => {
            modifyRef.value.show(currentForm.value);
        });
    },
    /**
     * 刷新表格数据
     */
    refresh: () => {
        tableRef.value.reload();
    },
});
const { add, columns, refresh } = toRefs(table);
</script>
<style scoped lang="less">
.monitor-report {
    display: flex;
    height: 100%;

    .tree-nav {
        width: 200px;
        margin-right: 16px;
        padding: 16px;
        height: 100%;
        background: white;
    }

    .content {
        flex: 1;
        height: 100%;
        background: white;

        .table-title {
            font-size: 20px;
            font-weight: 500;
        }

        .JSearch-warp {
            margin-bottom: 0;
        }
    }
}
</style>
